Coverage for .tox/cov/lib/python3.10/site-packages/confattr/__init__.py: 100%

1#!./runmodule.sh

2

3'''

4 Config Attributes

5

6 A python library to read and write config files

7 with a syntax inspired by vimrc and ranger config.

8'''

9

10 __version__ = '0.9.0-dev'

11

12 from .config import *

13 from .configfile import *

14

15 __all__ = [

16 # -------- for normal usage -------

17 # imported from config

18 'Config',

19 'DictConfig',

20 'ConfigTrackingChanges',

21 'MultiConfig',

22 'MultiDictConfig',

23 'ConfigId',

24 # imported from configfile

25 'ConfigFile',

26 'NotificationLevel',

27 'Message',

28 'ParseException',

29 # -------- for extending/customizing this package -------

30 # imported from config

31 'InstanceSpecificDictMultiConfig',

32 # imported from configfile

33 'DEFAULT_COMMAND',

34 'SectionLevel',

35 'FormattedWriter',

36 'ConfigFileWriter',

37 'HelpWriter',

38 'SaveKwargs',

39 'ParseLineKwargs',

40 'ConfigFileCommand',

41 'ConfigFileArgparseCommand',

42 'ArgumentParser',

43 'Set',

44 'Include',

45 'readable_quote',

46 'UiCallback',

47 'MultipleParseExceptions',

48]